@@ -9,6 +9,7 @@ import transaction
 import sqlahelper
 from bsddb import db
 from pyramid_rest.autotests import AutoTestManager
+from jsonschema._format import FormatChecker
 
 class registerResource:
     """
@@ -203,7 +204,7 @@ class validateRequest:
         self.cls = cls
     
     def _validateSchema(self, schema, data):
-        validator = Draft4Validator(schema)
+        validator = Draft4Validator(schema, format_checker = FormatChecker())
         
         Logger().decorators.info("Validating data %s with schema %s", pformat(data), pformat(schema))
         
@@ -223,9 +224,11 @@ class validateRequest:
         out = customValidator(self.validate)(resource_view)
         out.__doc__ = out.__doc__ or ""
         out.__doc__ += u"""
-    * Schema для валидации метода::
-    
-        %s
+
+* Schema для валидации метода::
+
+    %s
+
     """%(pformat(self.schema))
     
         
@@ -432,11 +435,11 @@ class ApplyMapper:
         
         _callback.__doc__ += u"""
         
-        .. warning::
-             **Метод маппируется!**. 
-        
-        Подробнее о маппинге метода:
-        %s
+.. warning::
+     **Метод маппируется!**. 
+
+Подробнее о маппинге метода:
+%s
         
         """%self.mapper.__doc__
         
@@ -489,9 +492,10 @@ class bindTable:
         _callback.__module__ = resource_view.__module__
         
         _callback.__doc__ += u"""
-            .. warning::
-            
-                Метод привязан к таблице %s! 
+        
+.. warning::
+
+    Метод привязан к таблице %s! 
                 
         """%self.table.__name__
         
