@@ -17,7 +17,8 @@ class Logger:
                        'app',
                        'decorators',
                        'view',
-                       'files']
+                       'files',
+                       'models']
     def __init__(self, app = None):
         for name in self.ALLOWED_LOGGERS:
             setattr(self, name, logging.getLogger(name))
